@@ -1,10 +1,11 @@
 import copy
+from enum import Enum
 from securesubmit.entities.credit import HpsCardHolder, HpsCreditCard
-from securesubmit.entities import HpsAddress
+from securesubmit.entities.core import HpsAddress
 from securesubmit.entities.check import HpsCheck, HpsCheckHolder
 from securesubmit.entities.gift import HpsGiftCard
-from securesubmit.infrastructure.enums import CheckTypeType, AccountTypeType, SecCode
-from securesubmit.services import HpsServicesConfig
+from securesubmit.infrastructure.enums import CheckTypeType, AccountTypeType
+from securesubmit.services.core import HpsServicesConfig
 
 
 class TestCardHolder(object):
@@ -73,6 +74,7 @@ class TestCheck(object):
     approve.sec_code = 'PPD'
     approve.account_type = AccountTypeType.checking
     approve.check_holder = copy.deepcopy(_check_holder)
+
     # check w/ invalid check holder
     invalid_check_holder = copy.deepcopy(approve)
     invalid_check_holder.check_holder.dl_number = ''
@@ -83,26 +85,6 @@ class TestCheck(object):
     decline = copy.deepcopy(approve)
     decline.routing_number = '490000034'
 
-    # certification check
-    certification = HpsCheck()
-    certification.account_number = '24413815'
-    certification.routing_number = '490000018'
-    certification.check_type = CheckTypeType.personal
-    certification.sec_code = SecCode.ppd
-    certification.account_type = AccountTypeType.checking
-
-    certification.check_holder = HpsCheckHolder()
-    certification.check_holder.address = HpsAddress()
-    certification.check_holder.address.address = '123 Main St.'
-    certification.check_holder.address.city = 'Downtown'
-    certification.check_holder.address.state = 'NJ'
-    certification.check_holder.address.zip = '12345'
-    certification.check_holder.dl_number = '09876543210'
-    certification.check_holder.dl_state = 'TX'
-    certification.check_holder.first_name = 'John'
-    certification.check_holder.last_name = 'Doe'
-    certification.check_holder.phone = '8003214567'
-
 
 class TestCreditCard(object):
     # valid visa
@@ -196,13 +178,5 @@ class TestServicesConfig(object):
     valid_services_config = HpsServicesConfig()
     valid_services_config.credential_token = 'pkapi_cert_P6dRqs1LzfWJ6HgGVZ'
     valid_services_config.secret_api_key = \
-        'skapi_cert_MYl2AQAowiQAbLp5JesGKh7QFkcizOP2jcX9BrEMqQ'
-    valid_services_config.service_uri = _service_uri
-
-    valid_e_gold_config = HpsServicesConfig()
-    valid_e_gold_config.site_id = '95881'
-    valid_e_gold_config.license_id = '95878'
-    valid_e_gold_config.device_id = '90911485'
-    valid_e_gold_config.username = '777700778679'
-    valid_e_gold_config.password = '$Test1234'
-    valid_e_gold_config.service_uri = _service_uri
+        'skapi_cert_MTp7AQBuokcAmMW80-VZoAsJWj74LZx4-CJKbu47mw'
+    valid_services_config.service_uri = _service_uri
\ No newline at end of file
